package com.aliwork.alimeetinguisdk.demo

import android.os.Bundle
import android.support.v4.app.FragmentActivity
import android.support.v7.app.AppCompatActivity
import android.text.TextUtils
import android.view.View
import android.widget.Toast
import com.afollestad.materialdialogs.MaterialDialog
import com.alibaba.alimeeting.uisdk.AliMeetingBrief
import com.alibaba.alimeeting.uisdk.AliMeetingJoinConfig
import com.alibaba.alimeeting.uisdk.AliMeetingUIManager
import kotlinx.android.synthetic.main.main_activity.*

class MainActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.main_activity)

        //在调用 AliMeetingUIManager.joinMeeting 之前调用即可
        initSDK()

        btnJoin.setOnClickListener {
            val meetingCode = editMeetingCode.text.toString()
            val userId = editUserId.text.toString().trim()

            if (TextUtils.isEmpty(meetingCode)) {
                Toast.makeText(this, "请输入会议口令", Toast.LENGTH_SHORT).show()
                return@setOnClickListener
            }
            if (TextUtils.isEmpty(userId)) {
                Toast.makeText(this, "请输入UserId", Toast.LENGTH_SHORT).show()
                return@setOnClickListener
            }

            queryMeetingInfo(meetingCode, userId)
        }
    }

    private fun queryMeetingInfo(meetingCode: String, userId: String) {
        //FIXME  ==== 通过meetingCode, userId获取入会的参数，返回的参数应该有
        //meetingAppId: String, meetingToken: String, meetingDomain: String,
        //meetingUUID: String, memberUUID: String, rateLink: String
        //其中rateLink 用于会后评价，可为空
        //获取到参数后，开始通过配置入会
        joinMeeting(
            meetingCode, userId, "xxx", "xxx", "xxx",
            "xxx", "xxx", "xxx"
        )
    }

    fun joinMeeting(
        meetingCode: String, userId: String,
        meetingAppId: String, meetingToken: String,
        meetingDomain: String, meetingUUID: String,
        memberUUID: String, rateLink: String?
    ) {
        AliMeetingUIManager.joinMeeting(
            this,
            AliMeetingJoinConfig.Builder().userId(userId)
                .securityTransport(false)
                .openCameraDefault(!defaultCloseCamera.isChecked)
                .muteAudioDefault(defaultMuteAudio.isChecked)
                .onlyMasterCanHangUp(onlyMasterHangup.isChecked)
                .onlyMasterCanMuteAudio(onlyMasterMute.isChecked)
                .meetingCode(meetingCode)
                .meetingDetailConfig(
                    meetingAppId, meetingToken, meetingDomain,
                    meetingCode, meetingUUID, memberUUID, rateLink
                )
                .builder()
        )
    }


    private fun initSDK() {
        //初始化分为两部分，
        //2. UI配置，目前仅支持邀请人定制，如果不设置AliMeetingUIManager.uiController， 则没有参会人列表不会有邀请人选项
        AliMeetingUIManager.uiController = object : AliMeetingUIManager.AliMeetingUiController {
            override fun onInviteAction(
                view: View, activity: FragmentActivity, meetingBrief: AliMeetingBrief
            ) {
                MaterialDialog.Builder(activity)
                    .items("分享到钉钉", "复制邀请信息")
                    .itemsCallback { _, _, which, _ ->
                        when (which) {
                            0 -> {
                                // 分享到钉钉
                                Toast.makeText(activity, "分享到钉钉", Toast.LENGTH_SHORT).show()
                            }
                            1 -> {
                                // 复制邀请信息
                                Toast.makeText(activity, "复制邀请信息", Toast.LENGTH_SHORT).show()
                            }
                            else -> {
                            }
                        }
                    }
                    .show()
            }

        }
    }

}
