package com.aliwork.alimeetingsdk.demo.network

import android.util.Log
import com.alibaba.fastjson.JSON
import com.aliwork.alimeetinguisdk.demo.ui.main.MeetingDetail
import okhttp3.*
import java.io.IOException
import java.security.cert.CertificateException
import java.security.cert.X509Certificate
import java.util.concurrent.TimeUnit
import javax.net.ssl.X509TrustManager


class MeetingDetailUseCase {
    private val TAG = "Meeting_DetailUseCase"

    private val okHttpClient: OkHttpClient by lazy {
        val certs = arrayOf<X509TrustManager>(object : X509TrustManager {
            override fun getAcceptedIssuers(): Array<X509Certificate?> {
                return arrayOfNulls(0)
            }

            @Throws(CertificateException::class)
            override fun checkServerTrusted(chain: Array<X509Certificate>, authType: String) {
            }

            @Throws(CertificateException::class)
            override fun checkClientTrusted(chain: Array<X509Certificate>, authType: String) {
            }
        })

        OkHttpClient.Builder()
            .connectTimeout(10, TimeUnit.SECONDS)
            .readTimeout(10, TimeUnit.SECONDS)
            .followRedirects(true)
            .followSslRedirects(true)
            .hostnameVerifier { hostname, session -> true }
            .build()
    }


    fun getDetail(userId: String, callerUid: String, meetingCode: String,
                  checkMeetingCodeUrl: String, callback: DetailCallBack) {
        Log.d(TAG, "getDetail userId:$userId callerUid:$callerUid meetingCode:$meetingCode checkMeetingCodeUrl:$checkMeetingCodeUrl")

        val formBody = FormBody.Builder()
            .add("userId", userId)
            .add("callerUid", callerUid)
            .add("meetingCode", meetingCode)
            .build()


        val request = Request.Builder()
            .url(checkMeetingCodeUrl)
            .post(formBody)
            .build()

        okHttpClient.newCall(request).enqueue(object : Callback {
            override fun onFailure(call: Call, e: IOException) {
                Log.d(TAG, "onFailure ", e)
                callback.onCompleted(false, null)
            }

            override fun onResponse(call: Call, response: Response) {
                if (response.isSuccessful) {
                    response.body()?.string()?.let { data ->
                        val meetingDetail = JSON.parseObject(
                            JSON.parseObject(data)
                                .getString("data"), MeetingDetail::class.java
                        )
                        Log.d(TAG, "get meeting detail: $data")
                        callback.onCompleted(true, meetingDetail)
                    } ?: onResponseEmpty(callback)
                } else {

                    Log.d(TAG, "onFailure ${response.code()}  ${response.message()}")
                    callback.onCompleted(false, null)
                }
            }
        })
    }

    private fun onResponseEmpty( callback: DetailCallBack) {
        callback.onCompleted(false, null)
    }
}

interface DetailCallBack {
    fun onCompleted(success: Boolean, detail: MeetingDetail?)
}